========
whattime
========

Checking of what kind a datetime object is.

Description
===========

whattime let’s you explore of what kind a certain datetime object is, if it e.g. is on a weekend, or in the evening.

Getting started
---------------

For quickly getting started, just import the ``whattime`` function and explore a date’s properties (see the `Get started example <examples/get_started.py>`_).

.. include:: examples/get_started.py
   :code: python

Besides checking all the time types you can also only check a certain category of types, e.g. info about the current day, or the time within a day seperately (see the `Single info type example <examples/using_certain_descriptors_only.py>`_).

.. include:: examples/using_certain_descriptors_only.py
   :code: python

